@@ -147,11 +147,7 @@ cipher_context_dispose (GObject *object)
 	CamelCipherContextPrivate *priv;
 
 	priv = CAMEL_CIPHER_CONTEXT (object)->priv;
-
-	if (priv->session != NULL) {
-		g_object_unref (priv->session);
-		priv->session = NULL;
-	}
+	g_clear_object (&priv->session);
 
 	/* Chain up to parent's dispose () method. */
 	G_OBJECT_CLASS (camel_cipher_context_parent_class)->dispose (object);
@@ -603,7 +599,7 @@ camel_cipher_context_verify_finish (CamelCipherContext *context,
 /**
  * camel_cipher_context_encrypt_sync:
  * @context: a #CamelCipherContext
- * @userid: key ID (or email address) to use when signing, or %NULL to not sign
+ * @userid: (nullable): key ID (or email address) to use when signing, or %NULL to not sign
  * @recipients: (element-type utf8): an array of recipient key IDs and/or email addresses
  * @ipart: clear-text #CamelMimePart
  * @opart: cipher-text #CamelMimePart
@@ -690,7 +686,7 @@ cipher_context_encrypt_thread (GTask *task,
 /**
  * camel_cipher_context_encrypt:
  * @context: a #CamelCipherContext
- * @userid: key id (or email address) to use when signing, or %NULL to not sign
+ * @userid: (nullable): key id (or email address) to use when signing, or %NULL to not sign
  * @recipients: (element-type utf8): an array of recipient key IDs and/or email addresses
  * @ipart: clear-text #CamelMimePart
  * @opart: cipher-text #CamelMimePart
