@@ -229,6 +229,10 @@ static struct {
 	{ "compare-date",
 	  G_STRUCT_OFFSET (CamelFolderSearchClass, compare_date),
 	  CAMEL_FOLDER_SEARCH_ALWAYS_ENTER },
+
+	{ "addressbook-contains",
+	  G_STRUCT_OFFSET (CamelFolderSearchClass, addressbook_contains),
+	  CAMEL_FOLDER_SEARCH_ALWAYS_ENTER },
 };
 
 G_DEFINE_TYPE_WITH_PRIVATE (CamelFolderSearch, camel_folder_search, G_TYPE_OBJECT)
@@ -342,6 +346,7 @@ check_header (CamelSExp *sexp,
 		const gchar *header = NULL, *charset = NULL;
 		gchar strbuf[32];
 		gint i, j;
+		gboolean is_message_id = FALSE;
 		camel_search_t type = CAMEL_SEARCH_TYPE_ASIS;
 		struct _camel_search_words *words;
 		CamelMimeMessage *message = NULL;
@@ -368,6 +373,8 @@ check_header (CamelSExp *sexp,
 		} else if (!g_ascii_strcasecmp (headername, "x-camel-mlist")) {
 			header = camel_message_info_get_mlist (search->priv->current);
 			type = CAMEL_SEARCH_TYPE_MLIST;
+		} else if (how == CAMEL_SEARCH_MATCH_EXACT && !g_ascii_strcasecmp (headername, "MESSAGE-ID")) {
+			is_message_id = TRUE;
 		} else {
 			message = ref_current_message (search);
 			if (message) {
@@ -417,6 +424,11 @@ check_header (CamelSExp *sexp,
 								how, type, charset);
 					}
 					camel_search_words_free (words);
+				} else if (is_message_id) {
+					guint64 message_id;
+
+					message_id = camel_folder_search_util_hash_message_id (argv[i]->value.string, TRUE);
+					truth = camel_message_info_get_message_id (search->priv->current) == message_id;
 				} else {
 					if (message) {
 						const CamelNameValueArray *headers = NULL;
@@ -584,7 +596,7 @@ match_words_1message (CamelDataWrapper *object,
 		/* for messages we only look at its contents */
 		truth = match_words_1message ((CamelDataWrapper *) containee, words, mask, cancellable);
 	} else if (camel_content_type_is (camel_data_wrapper_get_mime_type_field (CAMEL_DATA_WRAPPER (containee)), "text", "*")) {
-		/* for all other text parts, we look inside, otherwise we dont care */
+		/* for all other text parts, we look inside, otherwise we don't care */
 		CamelStream *stream;
 		GByteArray *byte_array;
 		const gchar *charset;
@@ -1791,6 +1803,68 @@ folder_search_compare_date (CamelSExp *sexp,
 	return res;
 }
 
+static CamelSExpResult *
+folder_search_addressbook_contains (CamelSExp *sexp,
+				    gint argc,
+				    CamelSExpResult **argv,
+				    CamelFolderSearch *search)
+{
+	CamelSExpResult *res;
+
+	r (printf ("executing addressbook-contains\n"));
+
+	if (!search->priv->current) {
+		res = camel_sexp_result_new (sexp, CAMEL_SEXP_RES_ARRAY_PTR);
+		res->value.ptrarray = g_ptr_array_new ();
+
+		return res;
+	}
+
+	res = camel_sexp_result_new (sexp, CAMEL_SEXP_RES_BOOL);
+	res->value.boolean = FALSE;
+
+	if (argc == 2) {
+		const gchar *book_uid, *header, *email_address = NULL;
+		gboolean address_set = FALSE;
+
+		if (argv[0]->type != CAMEL_SEXP_RES_STRING ||
+		    argv[1]->type != CAMEL_SEXP_RES_STRING)
+			return res;
+
+		book_uid = argv[0]->value.string;
+		header = argv[1]->value.string;
+
+		if (header && g_ascii_strcasecmp (header, "From") == 0) {
+			email_address = camel_message_info_get_from (search->priv->current);
+			address_set = TRUE;
+		} else if (header && g_ascii_strcasecmp (header, "To") == 0) {
+			email_address = camel_message_info_get_to (search->priv->current);
+			address_set = TRUE;
+		} else if (header && g_ascii_strcasecmp (header, "Cc") == 0) {
+			email_address = camel_message_info_get_cc (search->priv->current);
+			address_set = TRUE;
+		}
+
+		if (address_set) {
+			CamelStore *store;
+			CamelSession *session = NULL;
+
+			store = camel_folder_get_parent_store (search->priv->folder);
+			if (store)
+				session = camel_service_ref_session (CAMEL_SERVICE (store));
+
+			if (session) {
+				res->value.boolean = email_address && camel_session_addressbook_contains_sync (session,
+					book_uid, email_address, search->priv->cancellable, NULL);
+
+				g_object_unref (session);
+			}
+		}
+	}
+
+	return res;
+}
+
 static void
 camel_folder_search_class_init (CamelFolderSearchClass *class)
 {
@@ -1826,6 +1900,7 @@ camel_folder_search_class_init (CamelFolderSearchClass *class)
 	class->message_location = folder_search_message_location;
 	class->make_time = folder_search_make_time;
 	class->compare_date = folder_search_compare_date;
+	class->addressbook_contains = folder_search_addressbook_contains;
 }
 
 static void
@@ -2108,6 +2183,7 @@ do_search_in_memory (CamelFolder *search_in_folder,
 		"header-contains",
 		"header-has-words",
 		"header-ends-with",
+		"addressbook-contains",
 		NULL };
 	gint i;
 
@@ -2629,3 +2705,44 @@ camel_folder_search_util_compare_date (gint64 datetime1,
 
 	return dt1 - dt2;
 }
+
+/**
+ * camel_folder_search_util_hash_message_id:
+ * @message_id: a raw Message-ID header value
+ * @needs_decode: whether the @message_id requires camel_header_msgid_decode() first
+ *
+ * Calculates a hash of the Message-ID header value @message_id.
+ *
+ * Returns: hash of the @message_id, or 0 on any error.
+ *
+ * Since: 3.40
+ **/
+guint64
+camel_folder_search_util_hash_message_id (const gchar *message_id,
+					  gboolean needs_decode)
+{
+	GChecksum *checksum;
+	CamelSummaryMessageID message_id_struct;
+	gchar *msgid = NULL;
+	guint8 *digest;
+	gsize length;
+
+	if (!message_id)
+		return 0;
+
+	if (needs_decode)
+		msgid = camel_header_msgid_decode (message_id);
+
+	length = g_checksum_type_get_length (G_CHECKSUM_MD5);
+	digest = g_alloca (length);
+
+	checksum = g_checksum_new (G_CHECKSUM_MD5);
+	g_checksum_update (checksum, (guchar *) (msgid ? msgid : message_id), -1);
+	g_checksum_get_digest (checksum, digest, &length);
+	g_checksum_free (checksum);
+
+	memcpy (message_id_struct.id.hash, digest, sizeof (message_id_struct.id.hash));
+	g_free (msgid);
+
+	return message_id_struct.id.id;
+}
