@@ -23,10 +23,6 @@
 
 #include "camel-mime-filter-yenc.h"
 
-#define CAMEL_MIME_FILTER_YENC_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), CAMEL_TYPE_MIME_FILTER_YENC, CamelMimeFilterYencPrivate))
-
 struct _CamelMimeFilterYencPrivate {
 
 	CamelMimeFilterYencDirection direction;
@@ -38,7 +34,7 @@ struct _CamelMimeFilterYencPrivate {
 	guint32 crc;
 };
 
-G_DEFINE_TYPE (CamelMimeFilterYenc, camel_mime_filter_yenc, CAMEL_TYPE_MIME_FILTER)
+G_DEFINE_TYPE_WITH_PRIVATE (CamelMimeFilterYenc, camel_mime_filter_yenc, CAMEL_TYPE_MIME_FILTER)
 
 /* here we do all of the basic yEnc filtering */
 static void
@@ -53,7 +49,7 @@ mime_filter_yenc_filter (CamelMimeFilter *mime_filter,
 	CamelMimeFilterYencPrivate *priv;
 	gsize newlen = 0;
 
-	priv = CAMEL_MIME_FILTER_YENC_GET_PRIVATE (mime_filter);
+	priv = CAMEL_MIME_FILTER_YENC (mime_filter)->priv;
 
 	switch (priv->direction) {
 		case CAMEL_MIME_FILTER_YENC_DIRECTION_ENCODE:
@@ -162,7 +158,7 @@ mime_filter_yenc_complete (CamelMimeFilter *mime_filter,
 	CamelMimeFilterYencPrivate *priv;
 	gsize newlen = 0;
 
-	priv = CAMEL_MIME_FILTER_YENC_GET_PRIVATE (mime_filter);
+	priv = CAMEL_MIME_FILTER_YENC (mime_filter)->priv;
 
 	switch (priv->direction) {
 	case CAMEL_MIME_FILTER_YENC_DIRECTION_ENCODE:
@@ -204,7 +200,7 @@ mime_filter_yenc_reset (CamelMimeFilter *mime_filter)
 {
 	CamelMimeFilterYencPrivate *priv;
 
-	priv = CAMEL_MIME_FILTER_YENC_GET_PRIVATE (mime_filter);
+	priv = CAMEL_MIME_FILTER_YENC (mime_filter)->priv;
 
 	switch (priv->direction) {
 		case CAMEL_MIME_FILTER_YENC_DIRECTION_ENCODE:
@@ -224,8 +220,6 @@ camel_mime_filter_yenc_class_init (CamelMimeFilterYencClass *class)
 {
 	CamelMimeFilterClass *mime_filter_class;
 
-	g_type_class_add_private (class, sizeof (CamelMimeFilterYencPrivate));
-
 	mime_filter_class = CAMEL_MIME_FILTER_CLASS (class);
 	mime_filter_class->filter = mime_filter_yenc_filter;
 	mime_filter_class->complete = mime_filter_yenc_complete;
@@ -235,7 +229,7 @@ camel_mime_filter_yenc_class_init (CamelMimeFilterYencClass *class)
 static void
 camel_mime_filter_yenc_init (CamelMimeFilterYenc *filter)
 {
-	filter->priv = CAMEL_MIME_FILTER_YENC_GET_PRIVATE (filter);
+	filter->priv = camel_mime_filter_yenc_get_instance_private (filter);
 
 	filter->priv->part = 0;
 	filter->priv->pcrc = CAMEL_MIME_YENCODE_CRC_INIT;
@@ -257,7 +251,7 @@ camel_mime_filter_yenc_new (CamelMimeFilterYencDirection direction)
 	CamelMimeFilterYencPrivate *priv;
 
 	filter = g_object_new (CAMEL_TYPE_MIME_FILTER_YENC, NULL);
-	priv = CAMEL_MIME_FILTER_YENC_GET_PRIVATE (filter);
+	priv = CAMEL_MIME_FILTER_YENC (filter)->priv;
 
 	priv->direction = direction;
 
