@@ -47,6 +47,7 @@ struct _CamelIMAPXSettingsPrivate {
 	gboolean ignore_other_users_namespace;
 	gboolean ignore_shared_folders_namespace;
 	gboolean full_update_on_metered_network;
+	gboolean send_client_id;
 
 	CamelSortType fetch_order;
 };
@@ -79,7 +80,8 @@ enum {
 	PROP_USE_SUBSCRIPTIONS,
 	PROP_IGNORE_OTHER_USERS_NAMESPACE,
 	PROP_IGNORE_SHARED_FOLDERS_NAMESPACE,
-	PROP_FULL_UPDATE_ON_METERED_NETWORK
+	PROP_FULL_UPDATE_ON_METERED_NETWORK,
+	PROP_SEND_CLIENT_ID
 };
 
 G_DEFINE_TYPE_WITH_CODE (
@@ -258,6 +260,12 @@ imapx_settings_set_property (GObject *object,
 				CAMEL_IMAPX_SETTINGS (object),
 				g_value_get_boolean (value));
 			return;
+
+		case PROP_SEND_CLIENT_ID:
+			camel_imapx_settings_set_send_client_id (
+				CAMEL_IMAPX_SETTINGS (object),
+				g_value_get_boolean (value));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -458,6 +466,13 @@ imapx_settings_get_property (GObject *object,
 				camel_imapx_settings_get_full_update_on_metered_network (
 				CAMEL_IMAPX_SETTINGS (object)));
 			return;
+
+		case PROP_SEND_CLIENT_ID:
+			g_value_set_boolean (
+				value,
+				camel_imapx_settings_get_send_client_id (
+				CAMEL_IMAPX_SETTINGS (object)));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -810,6 +825,19 @@ camel_imapx_settings_class_init (CamelIMAPXSettingsClass *class)
 			G_PARAM_CONSTRUCT |
 			G_PARAM_EXPLICIT_NOTIFY |
 			G_PARAM_STATIC_STRINGS));
+
+	g_object_class_install_property (
+		object_class,
+		PROP_SEND_CLIENT_ID,
+		g_param_spec_boolean (
+			"send-client-id",
+			"Send Client ID",
+			"Whether to send client ID to the server",
+			FALSE,
+			G_PARAM_READWRITE |
+			G_PARAM_CONSTRUCT |
+			G_PARAM_EXPLICIT_NOTIFY |
+			G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -1174,7 +1202,7 @@ camel_imapx_settings_set_filter_junk_inbox (CamelIMAPXSettings *settings,
  *
  * Returns the custom IMAP namespace in which to find folders.
  *
- * Returns: the custom IMAP namespace, or %NULL
+ * Returns: (nullable): the custom IMAP namespace, or %NULL
  *
  * Since: 3.2
  **/
@@ -1195,7 +1223,7 @@ camel_imapx_settings_get_namespace (CamelIMAPXSettings *settings)
  *
  * The returned string should be freed with g_free() when no longer needed.
  *
- * Returns: a newly-allocated copy of #CamelIMAPXSettings:namespace
+ * Returns: (nullable): a newly-allocated copy of #CamelIMAPXSettings:namespace
  *
  * Since: 3.4
  **/
@@ -1220,7 +1248,7 @@ camel_imapx_settings_dup_namespace (CamelIMAPXSettings *settings)
 /**
  * camel_imapx_settings_set_namespace:
  * @settings: a #CamelIMAPXSettings
- * @namespace_: an IMAP namespace, or %NULL
+ * @namespace_: (nullable): an IMAP namespace, or %NULL
  *
  * Sets the custom IMAP namespace in which to find folders.  If @namespace_
  * is %NULL, the default namespace is used.
@@ -1259,7 +1287,7 @@ camel_imapx_settings_set_namespace (CamelIMAPXSettings *settings,
  * Returns the path to a real, non-virtual Junk folder to be used instead
  * of Camel's standard virtual Junk folder.
  *
- * Returns: path to a real junk folder
+ * Returns: (nullable): path to a real junk folder
  *
  * Since: 3.8
  **/
@@ -1280,7 +1308,7 @@ camel_imapx_settings_get_real_junk_path (CamelIMAPXSettings *settings)
  *
  * The returned string should be freed with g_free() when no longer needed.
  *
- * Returns: a newly-allocated copy of #CamelIMAPXSettings:real-junk-path
+ * Returns: (nullable): a newly-allocated copy of #CamelIMAPXSettings:real-junk-path
  *
  * Since: 3.8
  **/
@@ -1305,7 +1333,7 @@ camel_imapx_settings_dup_real_junk_path (CamelIMAPXSettings *settings)
 /**
  * camel_imapx_settings_set_real_junk_path:
  * @settings: a #CamelIMAPXSettings
- * @real_junk_path: path to a real Junk folder, or %NULL
+ * @real_junk_path: (nullable): path to a real Junk folder, or %NULL
  *
  * Sets the path to a real, non-virtual Junk folder to be used instead of
  * Camel's standard virtual Junk folder.
@@ -1339,7 +1367,7 @@ camel_imapx_settings_set_real_junk_path (CamelIMAPXSettings *settings,
  * Returns the path to a real, non-virtual Trash folder to be used instead
  * of Camel's standard virtual Trash folder.
  *
- * Returns: path to a real Trash folder
+ * Returns: (nullable): path to a real Trash folder
  *
  * Since: 3.8
  **/
@@ -1360,7 +1388,7 @@ camel_imapx_settings_get_real_trash_path (CamelIMAPXSettings *settings)
  *
  * The returned string should be freed with g_free() when no longer needed.
  *
- * Returns: a newly-allocated copy of #CamelIMAPXsettings:real-trash-path
+ * Returns: (nullable): a newly-allocated copy of #CamelIMAPXsettings:real-trash-path
  *
  * Since: 3.8
  **/
@@ -1385,7 +1413,7 @@ camel_imapx_settings_dup_real_trash_path (CamelIMAPXSettings *settings)
 /**
  * camel_imapx_settings_set_real_trash_path:
  * @settings: a #CamelIMAPXSettings
- * @real_trash_path: path to a real Trash folder, or %NULL
+ * @real_trash_path: (nullable): path to a real Trash folder, or %NULL
  *
  * Sets the path to a real, non-virtual Trash folder to be used instead of
  * Camel's standard virtual Trash folder.
@@ -1425,7 +1453,7 @@ camel_imapx_settings_set_real_trash_path (CamelIMAPXSettings *settings,
  * this option menas or how to use it.  Probably not worth exposing in a
  * graphical interface.
  *
- * Returns: shell command for connecting to the server, or %NULL
+ * Returns: (nullable): shell command for connecting to the server, or %NULL
  *
  * Since: 3.2
  **/
@@ -1446,7 +1474,7 @@ camel_imapx_settings_get_shell_command (CamelIMAPXSettings *settings)
  *
  * The returned string should be freed with g_free() when no longer needed.
  *
- * Returns: a newly-allocated copy of #CamelIMAPXSettings:shell-command
+ * Returns: (nullable): a newly-allocated copy of #CamelIMAPXSettings:shell-command
  *
  * Since: 3.4
  **/
@@ -1471,7 +1499,7 @@ camel_imapx_settings_dup_shell_command (CamelIMAPXSettings *settings)
 /**
  * camel_imapx_settings_set_shell_command:
  * @settings: a #CamelIMAPXSettings
- * @shell_command: shell command for connecting to the server, or %NULL
+ * @shell_command: (nullable): shell command for connecting to the server, or %NULL
  *
  * Sets an optional shell command used to establish an input/output stream
  * with an IMAP server.  Normally the input/output stream is established
@@ -1953,3 +1981,44 @@ camel_imapx_settings_set_full_update_on_metered_network (CamelIMAPXSettings *set
 
 	g_object_notify (G_OBJECT (settings), "full-update-on-metered-network");
 }
+
+/**
+ * camel_imapx_settings_get_send_client_id:
+ * @settings: a #CamelIMAPXSettings
+ *
+ * Returns whether to send client ID to the server, using the 'ID' extension (RFC 2971).
+ *
+ * Returns: whether to send client ID to the server
+ *
+ * Since: 3.44
+ **/
+gboolean
+camel_imapx_settings_get_send_client_id (CamelIMAPXSettings *settings)
+{
+	g_return_val_if_fail (CAMEL_IS_IMAPX_SETTINGS (settings), FALSE);
+
+	return settings->priv->send_client_id;
+}
+
+/**
+ * camel_imapx_settings_set_send_client_id:
+ * @settings: a #CamelIMAPXSettings
+ * @send_client_id: whether to send client ID to the server
+ *
+ * Sets whether to send client ID to the server, using the 'ID' extension (RFC 2971).
+ *
+ * Since: 3.44
+ **/
+void
+camel_imapx_settings_set_send_client_id (CamelIMAPXSettings *settings,
+					 gboolean send_client_id)
+{
+	g_return_if_fail (CAMEL_IS_IMAPX_SETTINGS (settings));
+
+	if ((settings->priv->send_client_id ? 1 : 0) == (send_client_id ? 1 : 0))
+		return;
+
+	settings->priv->send_client_id = send_client_id;
+
+	g_object_notify (G_OBJECT (settings), "send-client-id");
+}
