@@ -116,6 +116,7 @@ typedef struct _EWebDAVResource {
 	glong last_modified;
 	gchar *description;
 	gchar *color;
+	guint order; /* (guint) -1, if unknown */
 } EWebDAVResource;
 
 GType		e_webdav_resource_get_type		(void) G_GNUC_CONST;
@@ -130,13 +131,14 @@ EWebDAVResource *
 							 glong creation_date,
 							 glong last_modified,
 							 const gchar *description,
-							 const gchar *color);
+							 const gchar *color,
+							 guint order);
 EWebDAVResource *
 		e_webdav_resource_copy			(const EWebDAVResource *src);
 void		e_webdav_resource_free			(gpointer ptr /* EWebDAVResource * */);
 
 typedef enum {
-	E_WEBDAV_LIST_ALL		= 0xFFFFFFFF,
+	E_WEBDAV_LIST_ALL		= 0x00FFFFFF,
 	E_WEBDAV_LIST_NONE		= 0,
 	E_WEBDAV_LIST_SUPPORTS		= 1 << 0,
 	E_WEBDAV_LIST_ETAG		= 1 << 1,
@@ -147,15 +149,15 @@ typedef enum {
 	E_WEBDAV_LIST_LAST_MODIFIED	= 1 << 6,
 	E_WEBDAV_LIST_DESCRIPTION	= 1 << 7,
 	E_WEBDAV_LIST_COLOR		= 1 << 8,
-	E_WEBDAV_LIST_ONLY_CALENDAR	= 1 << 9,
-	E_WEBDAV_LIST_ONLY_ADDRESSBOOK	= 1 << 10
+	E_WEBDAV_LIST_ORDER		= 1 << 9,
+	E_WEBDAV_LIST_ONLY_CALENDAR	= 1 << 28,
+	E_WEBDAV_LIST_ONLY_ADDRESSBOOK	= 1 << 29
 } EWebDAVListFlags;
 
 /**
  * EWebDAVPropstatTraverseFunc:
  * @webdav: an #EWebDAVSession
- * @xpath_ctx: an #xmlXPathContextPtr
- * @xpath_prop_prefix: (nullable): an XPath prefix for the current prop element, without trailing forward slash
+ * @prop_node: an #xmlNode
  * @request_uri: a #SoupURI, containing the request URI, maybe redirected by the server
  * @href: (nullable): a full URI to which the property belongs, or %NULL, when not found
  * @status_code: an HTTP status code for this property
@@ -165,18 +167,15 @@ typedef enum {
  * e_webdav_session_report_sync() and other XML response with DAV:propstat
  * elements traversal functions.
  *
- * The @xpath_prop_prefix can be %NULL only once, for the first time,
- * which is meant to let the caller setup the @xpath_ctx, like to register
- * its own namespaces to it with e_xml_xpath_context_register_namespaces().
- * All other invocations of the function will have @xpath_prop_prefix non-%NULL.
+ * The @prop_node points to the actual property (prop) node and it can be examined
+ * with e_xml_find_child(), e_xml_find_children_nodes() and other provided XML helper functions.
  *
  * Returns: %TRUE to continue traversal of the returned response, %FALSE otherwise.
  *
  * Since: 3.26
  **/
 typedef gboolean (* EWebDAVPropstatTraverseFunc)	(EWebDAVSession *webdav,
-							 xmlXPathContext *xpath_ctx,
-							 const gchar *xpath_prop_prefix,
+							 xmlNode *prop_node,
 							 const SoupURI *request_uri,
 							 const gchar *href,
 							 guint status_code,
@@ -595,6 +594,8 @@ gboolean	e_webdav_session_principal_property_search_sync
 							 GError **error);
 gchar *		e_webdav_session_util_maybe_dequote	(gchar *text);
 void		e_webdav_session_util_free_privileges	(GNode *privileges); /* EWebDAVPrivilege * */
+gboolean	e_webdav_session_util_item_href_equal	(const gchar *href1,
+							 const gchar *href2);
 
 G_END_DECLS
 
