@@ -561,6 +561,24 @@ credentials_prompter_impl_oauth2_get_prompt_strings (ESourceRegistry *registry,
 	g_free (display_name);
 }
 
+static gchar *
+credentials_prompter_impl_oauth2_sanitize_host (gchar *host)
+{
+	if (!host || !*host)
+		return host;
+
+	if (*host == '[' && strchr (host, ':')) {
+		gint len = strlen (host);
+
+		if (len > 2 && host[len - 1] == ']') {
+			memmove (host, host + 1, len - 2);
+			host[len - 2] = '\0';
+		}
+	}
+
+	return host;
+}
+
 static void
 credentials_prompter_impl_oauth2_set_proxy (WebKitWebContext *web_context,
 					    ESourceRegistry *registry,
@@ -604,7 +622,7 @@ credentials_prompter_impl_oauth2_set_proxy (WebKitWebContext *web_context,
 		case E_PROXY_METHOD_MANUAL:
 			ignore_hosts = e_source_proxy_dup_ignore_hosts (proxy);
 
-			tmp = e_source_proxy_dup_socks_host (proxy);
+			tmp = credentials_prompter_impl_oauth2_sanitize_host (e_source_proxy_dup_socks_host (proxy));
 			if (tmp && *tmp) {
 				suri = soup_uri_new (NULL);
 				soup_uri_set_scheme (suri, "socks");
@@ -623,7 +641,7 @@ credentials_prompter_impl_oauth2_set_proxy (WebKitWebContext *web_context,
 			}
 			g_free (tmp);
 
-			tmp = e_source_proxy_dup_http_host (proxy);
+			tmp = credentials_prompter_impl_oauth2_sanitize_host (e_source_proxy_dup_http_host (proxy));
 			if (tmp && *tmp) {
 				suri = soup_uri_new (NULL);
 				soup_uri_set_scheme (suri, SOUP_URI_SCHEME_HTTP);
@@ -650,7 +668,7 @@ credentials_prompter_impl_oauth2_set_proxy (WebKitWebContext *web_context,
 			}
 			g_free (tmp);
 
-			tmp = e_source_proxy_dup_https_host (proxy);
+			tmp = credentials_prompter_impl_oauth2_sanitize_host (e_source_proxy_dup_https_host (proxy));
 			if (tmp && *tmp) {
 				suri = soup_uri_new (NULL);
 				soup_uri_set_scheme (suri, SOUP_URI_SCHEME_HTTP);
@@ -856,6 +874,7 @@ e_credentials_prompter_impl_oauth2_show_dialog (ECredentialsPrompterImplOAuth2 *
 		"enable-page-cache", FALSE,
 		"enable-plugins", FALSE,
 		"media-playback-allows-inline", FALSE,
+		"hardware-acceleration-policy", WEBKIT_HARDWARE_ACCELERATION_POLICY_NEVER,
 		NULL);
 
 	web_context = webkit_web_context_new ();
