@@ -27,6 +27,23 @@
 
 #include "client-test-utils.h"
 
+static const gchar *args_data_dir = NULL;
+
+void
+client_test_utils_read_args (gint argc,
+			     gchar **argv)
+{
+	gint ii;
+
+	for (ii = 0; ii < argc; ii++) {
+		if (g_strcmp0 (argv[ii], "--data-dir") == 0) {
+			if (ii + 1 < argc)
+				args_data_dir = argv[ii + 1];
+			break;
+		}
+	}
+}
+
 void
 print_email (EContact *contact)
 {
@@ -61,10 +78,16 @@ new_vcard_from_test_case (const gchar *case_name)
 	/* In the case of installed tests, they run in ${pkglibexecdir}/installed-tests
 	 * and the vcards are installed in ${pkglibexecdir}/installed-tests/vcards
 	 */
-	if (g_getenv ("TEST_INSTALLED_SERVICES") != NULL)
+	if (g_getenv ("TEST_INSTALLED_SERVICES") != NULL) {
 		filename = g_build_filename (INSTALLED_TEST_DIR, "vcards", case_filename, NULL);
-	else
-		filename = g_build_filename (SRCDIR, "..", "data", "vcards", case_filename, NULL);
+	} else {
+		if (!args_data_dir) {
+			g_warning ("Data directory not set, pass it with `--data-dir PATH`");
+			exit(1);
+		}
+
+		filename = g_build_filename (args_data_dir, case_filename, NULL);
+	}
 
 	file = g_file_new_for_path (filename);
 	if (!g_file_load_contents (file, NULL, &vcard, NULL, NULL, &error)) {
@@ -124,7 +147,7 @@ add_contact_from_test_case_verify (EBookClient *book_client,
 		g_error ("get contact sync: %s", error->message);
 
         /* verify the contact was added "successfully" (not thorough) */
-	g_assert (contacts_are_equal_shallow (contact_orig, contact_final));
+	g_assert_true (contacts_are_equal_shallow (contact_orig, contact_final));
 
 	if (contact)
                 *contact = contact_final;
@@ -153,7 +176,7 @@ add_contact_verify (EBookClient *book_client,
 		g_error ("get contact sync: %s", error->message);
 
         /* verify the contact was added "successfully" (not thorough) */
-	g_assert (contacts_are_equal_shallow (contact, contact_final));
+	g_assert_true (contacts_are_equal_shallow (contact, contact_final));
 
 	g_object_unref (contact_final);
 	g_free (uid);
