@@ -201,6 +201,9 @@ main (gint argc,
 	g_type_init ();
 #endif
 	g_test_init (&argc, &argv, NULL);
+	g_test_bug_base ("https://gitlab.gnome.org/GNOME/evolution-data-server/");
+
+	data_test_utils_read_args (argc, argv);
 
 	for (i = 0; i < G_N_ELEMENTS (closures); i++) {
 		gchar *path;
@@ -230,5 +233,5 @@ main (gint argc,
 		g_free (path);
 	}
 
-	return e_test_server_utils_run_full (0);
+	return e_test_server_utils_run_full (argc, argv, 0);
 }
