@@ -1,17 +1,17 @@
 /*
  * e-source-registry-test.c
  *
- * This program is free software; you can redistribute it and/or modify it
+ * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
- * This library is distributed in the hope that it will be useful, but
+ * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -154,7 +154,7 @@ main (gint argc,
 		test_remove_source,
 		e_test_server_utils_teardown);
 
-	retval = e_test_server_utils_run ();
+	retval = e_test_server_utils_run (argc, argv);
 
 	/* XXX Something is leaking a GDBusConnection reference.
 	 *     Leave this disabled until I can track it down. */
